import React, { useState, useEffect, useRef } from 'react';
import { LexicalComposer } from '@lexical/react/LexicalComposer';
import { RichTextPlugin } from '@lexical/react/LexicalRichTextPlugin';
import { ContentEditable } from '@lexical/react/LexicalContentEditable';
import { useLexicalComposerContext } from '@lexical/react/LexicalComposerContext';
import { LexicalErrorBoundary } from '@lexical/react/LexicalErrorBoundary';
import { LexicalEditor, EditorState } from 'lexical';
import { $generateHtmlFromNodes } from "@lexical/html";
import { MyOnChangePlugin } from './plugins/StateChangePlugin';
import { ToolbarPlugin } from './plugins/ToolbarPlugin';
import { InsertVariablesPlugin } from './plugins/InsertVariablesPlugin';
import { ErrorHandler } from './ErrorHandler';
import { Placeholder } from './Placeholder';
import { VariableNode } from './VariableNode';
import { fontFamily } from 'html2canvas/dist/types/css/property-descriptors/font-family';

type TextEditorProps = {
  initialContent?: string;
  onContentChange?: (content: string) => void;
  showToolbar: boolean;
  placeholder?: string;
};

export function TextEditor({ editorState, setEditorState, showToolbar, placeholder }: TextEditorProps) {
  function onChange(editorState: EditorState, editor: LexicalEditor) {
    setEditorState(editorState);
    editor.read(() => {
      const html = $generateHtmlFromNodes(editor)
      text.current = html;
    });
  }

  const text = useRef<string>("hai");

  const initialConfig = {
    namespace: 'MyEditor',
    theme,
    onError: ErrorHandler,
    nodes: [ VariableNode ],
  };

  return (
    <LexicalComposer initialConfig={initialConfig}>
      {showToolbar && <ToolbarPlugin />}
      <div className="relative border rounded">
        <RichTextPlugin
          contentEditable={<ContentEditable className="border min-h-24 p-3" />}
          placeholder={<Placeholder placeholder={placeholder} />}
          ErrorBoundary={LexicalErrorBoundary}
        />
      </div>
      <InsertVariablesPlugin />
      <MyOnChangePlugin onChange={onChange} />
      <InsertVariablesPlugin />
      <br /><b>Debug:</b>
      <div style={{fontFamily: 'monospace'}}>
        { text.current }
      </div>
    </LexicalComposer>
  );
}
