import { createSlice, PayloadAction } from '@reduxjs/toolkit';
import type { RootState } from './store';

export interface Alert {
  id: string;
  name: string;
  recipients: string[];
  template: string;
  frequency: string;
}

export interface AlertsState {
  alerts: Alert[];
}

const initialAlertsState: AlertsState = {
  alerts: [],
};

const alertsSlice = createSlice({
  name: 'alerts',
  initialState: initialAlertsState,
  reducers: {
    setAlerts: (state: AlertsState, action: PayloadAction<Alert[]>) => {
      state.alerts = action.payload;
    },
    addAlert: (state: AlertsState, action: PayloadAction<Alert>) => {
      state.alerts.push(action.payload);
    },
    removeAlert: (state: AlertsState, action: PayloadAction<string>) => {
      state.alerts = state.alerts.filter(alert => alert.name !== action.payload);
    },
  },
});

export const { setAlerts, addAlert, removeAlert } = alertsSlice.actions;
export const selectAlerts = (state: RootState) => state.alerts.alerts;
export default alertsSlice.reducer;
