import { createSlice, PayloadAction} from '@reduxjs/toolkit';
import type { RootState } from './store';

export interface ReportTemplate {
  id: string;
  name: string;
  recipients: string[];
  frequency: string | number;
  template: string;
}

export interface ReportTemplatesState {
  templates: ReportTemplate[];
}


const initialTemplates: ReportTemplate[] = [
  {
    id: 'template1',
    name: 'Weekly Report',
    recipients: ['test1@graphpolaris.com'],
    frequency: 'Weekly',
    template: '<p>This is a weekly report template.</p>',
  },
  {
    id: 'template2',
    name: 'Daily Report',
    recipients: ['test2@graphpolaris.com'],
    frequency: 'Daily',
    template: '<p>This is a daily report template.</p>',
  },
];

const initialState: ReportTemplatesState = {
  templates: initialTemplates,
};


export const reportTemplatesSlice = createSlice({
  name: 'reportTemplates',
  initialState,
  reducers: {
    addTemplate: (state, action: PayloadAction<ReportTemplate>) => {
      state.templates.push(action.payload);
    },
    updateTemplate: (state, action: PayloadAction<ReportTemplate>) => {
      const index = state.templates.findIndex((template) => template.id === action.payload.id);
      if (index !== -1) {
        state.templates[index] = action.payload;
      }
    },
    deleteTemplate: (state, action: PayloadAction<string>) => {
      state.templates = state.templates.filter((template) => template.id !== action.payload);
    },
  },
});

export const { addTemplate, updateTemplate, deleteTemplate } = reportTemplatesSlice.actions;
export const selectReportTemplates = (state: RootState) => state.reportTemplates.templates;
export default reportTemplatesSlice.reducer;