import React, { useState, useCallback, useEffect} from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { Dialog, DialogContent } from '../components';
import { SettingsPanel } from './SettingsPanel';
import { MonitorType, Sidebar } from './components/Sidebar';
import { RootState } from '../data-access';
import { addTemplate, ReportTemplate, updateTemplate} from '../data-access/store/reportTemplateSlice';
import { v4 as uuidv4 } from 'uuid';
import { useReportTemplates } from '../data-access';
import { useAppDispatch } from '../data-access';
import { Alert } from '../data-access/store/alertTemplateSlice';

type Props = {
  open: boolean;
  onClose: () => void;
};


export function InsightDialog(props: Props) {
  const dispatch = useAppDispatch();
  const reportTemplates = useReportTemplates();
  const alerts: Alert[] = useSelector((state: RootState) => state.alerts.alerts || []);
  const [adding, setAdding] = useState<boolean>(false);
  const [active, setActive] = useState<string>('');
  const [activeCategory, setActiveCategory] = useState<MonitorType | undefined>(undefined);

  const handleChangeActive = useCallback((category: MonitorType, id: string) => {
    setActive(id);
    setActiveCategory(category);
    setAdding(false)
  }, []);

  const handleSaveTemplate = useCallback((templateData: ReportTemplate) => {
    const existingTemplate = reportTemplates.find((t) => t.id === templateData.id);

    if (existingTemplate) {
      const updatedTemplate: ReportTemplate = {
        ...existingTemplate,
        ...templateData,
      };
      dispatch(updateTemplate(updatedTemplate));
      setActive(updatedTemplate.id);
    } else {
      dispatch(addTemplate(templateData));
      setActive(templateData.id);
    }
    setAdding(false);
  }, [dispatch, reportTemplates]);

  return (
    <Dialog
      open={props.open}
      onOpenChange={(ret) => {
        if (!ret) props.onClose();
      }}
    >
      <DialogContent className="w-5/6 h-5/6 rounded-none py-0 px-0">
        <div className="flex w-full h-full">
          <Sidebar
            reports={reportTemplates}
            alerts={alerts}
            changeActive={handleChangeActive}
            setAdding={setAdding}
            setActiveCategory={setActiveCategory}
          />
          <SettingsPanel
            activeCategory={activeCategory}
            active={active}
            adding={adding}
            setAdding={setAdding}
            setActiveCategory={setActiveCategory}
            setActive={setActive}
            onSaveTemplate={handleSaveTemplate}
            templates={reportTemplates}
          />
        </div>
      </DialogContent>
    </Dialog>
  );
}
