import React from 'react';
import { ReportingForm } from './reporting/ReportingForm';
import { AlertingForm } from './alerting/AlertingForm';
import { AddItem } from './components/AddItem';
import { StartScreen } from './components/StartScreen';
import { MonitorType } from './components/Sidebar';
import { ReportTemplate } from '../data-access/store/reportTemplateSlice';
import { v4 as uuidv4 } from 'uuid';

type Props = {
  active: string;
  activeCategory: MonitorType | undefined;
  adding: boolean;
  setAdding: (val: boolean) => void;
  setActiveCategory: (val: MonitorType | undefined) => void;
  setActive: (val: string) => void;
  onSaveTemplate: (templateData: ReportTemplate) => void;
  templates?: ReportTemplate[];
};

export function SettingsPanel(props: Props) {
  const {
    active,
    activeCategory,
    adding,
    setAdding,
    setActiveCategory,
    setActive,
    onSaveTemplate,
    templates = [],
  } = props;

  const activeTemplate = templates.find((template) => template.id === active);

  const handleAddItem = (name: string) => {
    if (activeCategory === 'report') {
      const newTemplate: ReportTemplate = {
        id: uuidv4(),
        name,
        recipients: [],
        frequency: 'Daily',
        template: '',
      };
      console.log('SettingsPanel: Creating new template:', newTemplate);
      onSaveTemplate(newTemplate);
      setAdding(false);
      setActive(newTemplate.id);
      setActiveCategory('report')
    }
  };

  const handleSaveTemplate = (templateData: Omit<ReportTemplate, 'id'>) => {
    const fullTemplateData: ReportTemplate = {
      ...templateData,
      id: activeTemplate?.id || '',
    };
    onSaveTemplate(fullTemplateData);
  };

  const renderContent = () => {
    if (adding) {
      if (activeCategory === 'report') {
      return (
        <AddItem
          category={activeCategory as MonitorType}
          onAdd={handleAddItem}
        />
      );
    }

    return (
      <AddItem
        category={activeCategory as MonitorType}
        onAdd={handleAddItem}
      />
    );
  }


    if (!activeCategory || !active) {
      return (
        <StartScreen
          setAdding={setAdding}
          setActiveCategory={setActiveCategory}
        />
      );
    }

    switch (activeCategory) {
      case 'report':
        return (
          <ReportingForm
            onSave={onSaveTemplate}
            initialData={activeTemplate}
            activeTemplate={active}
          />
        );
      //case 'alert':
       // return (
         // <AlertingForm
          //  initialData={activeAlert}
          ///>
       // );
      default:
        return null;
    }
  };

  return (
    <div className="flex-1 p-4 overflow-auto">
      {renderContent()}
    </div>
  );
}
