import React, { useState } from 'react';
import { Accordion, AccordionItem, AccordionHead, AccordionBody } from '../../components/accordion';
import { TextEditor } from '../../components/textEditor';
import { EditorState , createEditor} from 'lexical';
import { Alert } from '../../data-access/store/alertTemplateSlice';

type Props = {
  initialData?: Alert;
  onSave: (alertData: Alert) => void;
};

export function AlertingForm({ initialData, onSave }: Props) {
  const [editorState, setEditorState] = useState<EditorState | undefined>(
    initialData?.template ? createEditor().parseEditorState(initialData.template) : undefined
  );
  const [recipients, setRecipients] = useState<string>(initialData?.recipients.join(', ') || '');

  const handleSave = () => {
    const updatedAlert: Alert = {
      ...initialData,
      recipients: recipients.split(',').map(r => r.trim()),
      template: JSON.stringify(editorState?.toJSON() ?? ''),
      frequency: initialData?.frequency ?? 'Immediate',
    };
    onSave(updatedAlert);
  };

  return (
    <div>
      <span className="text-lg text-secondary-600 font-bold mb-4">Alert ID: {initialData?.id || 'New Alert'}</span>
      <Accordion defaultOpenAll={true} className="border-t divide-y">
        <AccordionItem className="pt-2 pb-4">
          <AccordionHead showArrow={false}>
            <span className="font-semibold">Recipient(s)</span>
          </AccordionHead>
          <AccordionBody>
            <div>
              <input 
                className="border w-full p-2" 
                value={recipients} 
                onChange={(e) => setRecipients(e.target.value)}
                placeholder="Enter recipients, separated by commas"
              />
            </div>
          </AccordionBody>
        </AccordionItem>
        <AccordionItem className="pt-2 pb-4">
          <AccordionHead showArrow={false}>
            <span className="font-semibold">Alerting text</span>
          </AccordionHead>
          <AccordionBody>
            <TextEditor
              editorState={editorState}
              setEditorState={setEditorState}
              showToolbar={true}
              placeholder="Start typing your alert template..."
            />
          </AccordionBody>
        </AccordionItem>
      </Accordion>
      <button 
        className="mt-4 px-4 py-2 bg-blue-500 text-white rounded"
        onClick={handleSave}
      >
        Save Alert
      </button>
    </div>
  );
}