import React from 'react';
import { Button } from '../../components';
import { Accordion, AccordionBody, AccordionHead, AccordionItem } from '../../components/accordion';
import { ReportTemplate } from '../../data-access/store/reportTemplateSlice';
import { Alert } from '../../data-access/store/alertTemplateSlice';


export type MonitorType = 'report' | 'alert';

type SidebarProps = {
  reports: ReportTemplate[];
  alerts: Alert[];
  changeActive: (category: MonitorType, val: string) => void;
  setAdding: (val: boolean) => void;
  setActiveCategory: (val: MonitorType | undefined) => void;
};

export function Sidebar(props: SidebarProps) {
  const reports = props.reports || [];
  const alerts = props.alerts || [];
  console.log('Reports in Sidebar:', props.reports);

  return (
    <div className="w-1/4 border-r overflow-auto flex flex-col h-full">
      <span className="text-lg text-secondary-700 font-semibold px-2 py-4">Insight Sharing</span>
      <Accordion defaultOpenIndex={0}>
        <AccordionItem className="">
          <AccordionHead className="border-b bg-secondary-50 hover:bg-secondary-100 p-1">
            <div className="w-full flex justify-between">
              <span className="font-semibold">Reports</span>
              <div
                onClick={(e) => {
                  props.setAdding(true);
                  props.setActiveCategory('report');
                  e.stopPropagation();
                }}
              >
                <Button
                  as={'a'}
                  variantType="secondary"
                  variant="ghost"
                  size="xs"
                  iconComponent="icon-[ic--outline-add]"
                  onClick={() => {}}
                />
              </div>
            </div>
          </AccordionHead>
          <AccordionBody className="ml-0">
            <ul className="space-y-2">
              {props.reports.map((template) => (
                <li
                  key={template.id}
                  className="cursor-pointer p-2 hover:bg-secondary-50"
                  onClick={() => {
                    props.changeActive('report', template.id);
                    props.setAdding(false);
                  }}
                >
                  {template.name}
                </li>
              ))}
            </ul>
          </AccordionBody>
        </AccordionItem>
        <AccordionItem>
          <AccordionHead className="border-b bg-secondary-50 hover:bg-secondary-100 p-1">
            <div className="w-full flex justify-between">
              <span className="font-semibold">Alerts</span>
              <div
                onClick={(e) => {
                  props.setAdding(true);
                  props.setActiveCategory('alert');
                  e.stopPropagation();
                }}
              >
                <Button
                  as={'a'}
                  variantType="secondary"
                  variant="ghost"
                  size="xs"
                  iconComponent="icon-[ic--outline-add]"
                  onClick={() => {}}
                />
              </div>
            </div>
          </AccordionHead>
          <AccordionBody className="ml-0">
            <ul className="space-y-2">
              {props.alerts.map((alert) => (
                <li
                  key={alert.id}
                  className="cursor-pointer p-2 hover:bg-secondary-50"
                  onClick={() => {
                    props.changeActive('alert', alert.id);
                    props.setAdding(false);
                  }}
                >
                  {alert.name}
                </li>
              ))}
            </ul>
          </AccordionBody>
        </AccordionItem>
      </Accordion>
    </div>
  );
}
